==================================
``psyclone.psyir.nodes.codeblock``
==================================

.. automodule:: psyclone.psyir.nodes.codeblock

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.codeblock
